==> dde-network-core_1.0.47.orig.tar.xz: dde-network-core-1.0.47/dss-network-plugin/translations/dss-network-plugin_fi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fi" version="2.1">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>1 uusi viesti</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Connecting %1</source>
        <translation>Yhdistää %1</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 yhdistetty</translation>
    </message>
    <message>
        <source>%1 disconnected</source>
        <translation>%1 katkaistu</translation>
    </message>
    <message>
        <source>Unable to connect %1, please check your router or net cable.</source>
        <translation>Ei voitu yhdistää %1, tarkista reititin tai verkkokaapeli.</translation>
    </message>
    <message>
        <source>Unable to connect %1, please keep closer to the wireless router</source>
        <translation>Ei voitu yhdistää %1, pysyttele lähempänä langatonta reititintä</translation>
    </message>
    <message>
        <source>Connection failed, unable to connect %1, wrong password</source>
        <translation>Yhteys kohteeseen %1 epäonnistui, väärä salasana</translation>
    </message>
    <message>
        <source>Password is required to connect %1</source>
        <translation>Salasana tarvitaan yhteydelle %1</translation>
    </message>
    <message>
        <source>The %1 802.11 WLAN network could not be found</source>
        <translation>%1 802.11 WLAN-verkkoa ei löytynyt</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Wired Connection</source>
        <translation>Verkkokaapeli</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Tukiasema</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protokolla</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Suojaustyyppi</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Taajuusalue</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kanava</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Liitäntä</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Verkkopeite</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Yhdyskäytävä</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Ensisijainen DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Etuliite</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Nopeus</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Laite suljettu</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Yhdistetty, mutta ei internet osoitetta</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Ei yhteyttä</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Verkkokaapeli irrotettu</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Yhdistää</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Todennus</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Hakee IP osoitetta</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Yhdistetty</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Katkaistu</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP ristiriita</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Epäonnistui</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Osoitteen haku</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Kaapeli</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Kaapeli %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Langaton verkko</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Langaton verkko: %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Laite suljettu</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Verkkokaapeli irrotettu</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Ei yhteyttä</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Yhdistää</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Yhdistetty, mutta ei internet osoitetta</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Yhteys epäonnistui</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP ristiriita</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Poista kiinteä yhteys</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Kytke kiinteä yhteys</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Poista langaton käytöstä</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Kytke langaton käyttöön</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Poista verkko käytöstä</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Kytke verkko käyttöön</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Verkon asetukset</translation>
    </message>
</context>
</TS>

==> dde-network-core_1.1.5.orig.tar.xz: dde-network-core-1.1.5/dss-network-plugin/translations/dss-network-plugin_fi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>1 uusi viesti</translation>
    </message>
</context>
<context>
    <name>DeviceControllItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>Langaton verkko</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Kaapeli</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Connecting %1</source>
        <translation>Yhdistää %1</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 yhdistetty</translation>
    </message>
    <message>
        <source>%1 disconnected</source>
        <translation>%1 katkaistu</translation>
    </message>
    <message>
        <source>Unable to connect %1, please check your router or net cable.</source>
        <translation>Ei voitu yhdistää %1, tarkista reititin tai verkkokaapeli.</translation>
    </message>
    <message>
        <source>Unable to connect %1, please keep closer to the wireless router</source>
        <translation>Ei voitu yhdistää %1, pysyttele lähempänä langatonta reititintä</translation>
    </message>
    <message>
        <source>Connection failed, unable to connect %1, wrong password</source>
        <translation>Yhteys kohteeseen %1 epäonnistui, väärä salasana</translation>
    </message>
    <message>
        <source>Password is required to connect %1</source>
        <translation>Salasana tarvitaan yhteydelle %1</translation>
    </message>
    <message>
        <source>The %1 802.11 WLAN network could not be found</source>
        <translation>%1 802.11 WLAN-verkkoa ei löytynyt</translation>
    </message>
</context>
<context>
    <name>WirelessItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>Yhdistä piilotettuun verkkoon</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Salasana</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Peruuta</translation>
    </message>
    <message>
        <source>Connect</source>
        <comment>button</comment>
        <translation>Yhdistä</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>Nimi (SSID)</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Tukiasema</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protokolla</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Suojaustyyppi</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kanava</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Taajuusalue</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Liitäntä</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Verkkopeite</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Yhdyskäytävä</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Ensisijainen DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Etuliite</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Nopeus</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Laite suljettu</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Yhdistetty, mutta ei internet osoitetta</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Ei yhteyttä</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Verkkokaapeli irrotettu</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Yhdistää</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Todennus</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Hakee IP osoitetta</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Yhdistetty</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Katkaistu</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP ristiriita</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Epäonnistui</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Osoitteen haku</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Kaapeli</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Kaapeli %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Langaton verkko</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Langaton verkko: %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Laite suljettu</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Verkkokaapeli irrotettu</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Ei yhteyttä</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Yhdistää</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Yhdistetty, mutta ei internet osoitetta</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Yhteys epäonnistui</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP ristiriita</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Poista kiinteä yhteys</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Kytke kiinteä yhteys</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Poista langaton käytöstä</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Kytke langaton käyttöön</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Poista verkko käytöstä</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Kytke verkko käyttöön</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Verkon asetukset</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Wired Connection</source>
        <translation>Verkkokaapeli</translation>
    </message>
</context>
</TS>
